@@ -6,3 +6,16 @@ from .scrapybara import ScrapybaraBrowser, ScrapybaraUbuntu
 from .operator import Operator
 from .agent import ComputerAgent
 from .version import __version__
+
+
+__all__ = [
+    Computer,
+    BrowserbaseBrowser,
+    LocalPlaywrightComputer,
+    DockerComputer,
+    ScrapybaraBrowser,
+    ScrapybaraUbuntu,
+    Operator,
+    ComputerAgent,
+    __version__,
+]
